@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/pkg/bin/python3.12
 # coding=utf-8
 #
 # Copyright (C) 2010 Craig Marshall, craig9 [at] gmail.com
@@ -25,14 +25,19 @@ font.
 It can also replace all fonts indiscriminately, and list all fonts
 currently being used.
 """
-import inkex
 
-text_tags = ['{http://www.w3.org/2000/svg}tspan',
-                            '{http://www.w3.org/2000/svg}text',
-                            '{http://www.w3.org/2000/svg}flowRoot',
-                            '{http://www.w3.org/2000/svg}flowPara',
-                            '{http://www.w3.org/2000/svg}flowSpan']
-font_attributes = ['font-family', '-inkscape-font-specification']
+import inkex
+from inkex.localization import inkex_gettext as _
+
+text_tags = [
+    "{http://www.w3.org/2000/svg}tspan",
+    "{http://www.w3.org/2000/svg}text",
+    "{http://www.w3.org/2000/svg}flowRoot",
+    "{http://www.w3.org/2000/svg}flowPara",
+    "{http://www.w3.org/2000/svg}flowSpan",
+]
+font_attributes = ["font-family", "-inkscape-font-specification"]
+
 
 def set_font(node, new_font, style=None):
     """
@@ -44,15 +49,16 @@ def set_font(node, new_font, style=None):
     """
     dirty = False
     if not style:
-        style = get_style(node)
+        style = node.style
     if style:
         for att in font_attributes:
             if att in style:
                 style[att] = new_font
-                set_style(node, style)
+                node.style = style
                 dirty = True
     return dirty
 
+
 def find_replace_font(node, find, replace):
     """
     Searches the relevant font attributes/styles of node for find, and
@@ -61,20 +67,22 @@ def find_replace_font(node, find, replace):
     Returns a dirty boolean flag
     """
     dirty = False
-    style = get_style(node)
+    style = node.style
     if style:
         for att in font_attributes:
-            if att in style and style[att].strip().lower() == find:
+            if style(att).strip().lower() == find:
                 set_font(node, replace, style)
                 dirty = True
     return dirty
 
+
 def is_styled_text(node):
     """
     Returns true if the tag in question is a "styled" element that
     can hold text.
     """
-    return node.tag in text_tags and 'style' in node.attrib
+    return node.tag in text_tags and "style" in node.attrib
+
 
 def is_text(node):
     """
@@ -84,26 +92,13 @@ def is_text(node):
     return node.tag in text_tags
 
 
-def get_style(node):
-    """
-    Sugar coated way to get style dict from a node
-    """
-    if 'style' in node.attrib:
-        return dict(inkex.Style.parse_str(node.attrib['style']))
-
-def set_style(node, style):
-    """
-    Sugar coated way to set the style dict, for node
-    """
-    node.attrib['style'] = str(inkex.Style(style))
-
 def get_fonts(node):
     """
     Given a node, returns a list containing all the fonts that
     the node is using.
     """
     fonts = []
-    s = get_style(node)
+    s = node.style
     if not s:
         return fonts
     for a in font_attributes:
@@ -111,13 +106,20 @@ def get_fonts(node):
             fonts.append(s[a])
     return fonts
 
+
 def report_replacements(num):
     """
     Sends a message to the end user showing success of failure
     of the font replacement
     """
     if num == 0:
-        inkex.errormsg(_('Couldn\'t find anything using that font, please ensure the spelling and spacing is correct.'))
+        inkex.errormsg(
+            _(
+                "Couldn't find anything using that font, please ensure the spelling "
+                "and spacing is correct."
+            )
+        )
+
 
 def report_findings(findings):
     """
@@ -127,14 +129,16 @@ def report_findings(findings):
         inkex.errormsg(_("Didn't find any fonts in this document/selection."))
     else:
         if len(findings) == 1:
-            inkex.errormsg(_(u"Found the following font only: %s") % findings[0])
+            inkex.errormsg(_("Found the following font only: %s") % findings[0])
         else:
-            inkex.errormsg(_(u"Found the following fonts:\n%s") % '\n'.join(findings))
+            inkex.errormsg(_("Found the following fonts:\n%s") % "\n".join(findings))
+
 
 class ReplaceFont(inkex.EffectExtension):
     """
     Replaces all instances of one font with another
     """
+
     def add_arguments(self, pars):
         pars.add_argument("--fr_find")
         pars.add_argument("--fr_replace")
@@ -164,7 +168,7 @@ class ReplaceFont(inkex.EffectExtension):
 
         selected = self.svg
         if scope == "selection_only":
-            selected = self.svg.selected.values()
+            selected = self.svg.selection.values()
 
         for item in selected:
             items.extend(self.find_child_text_items(item))
@@ -209,8 +213,10 @@ class ReplaceFont(inkex.EffectExtension):
 
     def effect(self):
         if not self.options.action:
-            return inkex.errormsg("Nothing to do, no action specified.")
-        action = self.options.action.strip("\"") # TODO Is this a bug? (Extra " characters)
+            return inkex.errormsg(_("Nothing to do, no action specified."))
+        action = self.options.action.strip(
+            '"'
+        )  # TODO Is this a bug? (Extra " characters)
         scope = self.options.scope
 
         relevant_items = self.relevant_items(scope)
@@ -218,19 +224,26 @@ class ReplaceFont(inkex.EffectExtension):
         if action == "find_replace":
             find = self.options.fr_find
             if find is None or find == "":
-                return inkex.errormsg(_("Please enter a search string in the find box."))
+                return inkex.errormsg(
+                    _("Please enter a search string in the find box.")
+                )
             find = find.strip().lower()
             replace = self.options.fr_replace
             if replace is None or replace == "":
-                return inkex.errormsg(_("Please enter a replacement font in the replace with box."))
+                return inkex.errormsg(
+                    _("Please enter a replacement font in the replace with box.")
+                )
             self.find_replace(relevant_items, find, replace)
         elif action == "replace_all":
             replace = self.options.r_replace
             if replace is None or replace == "":
-                return inkex.errormsg(_("Please enter a replacement font in the replace all box."))
+                return inkex.errormsg(
+                    _("Please enter a replacement font in the replace all box.")
+                )
             self.replace_all(relevant_items, replace)
         elif action == "list_only":
             self.list_all(relevant_items)
 
+
 if __name__ == "__main__":
     ReplaceFont().run()
