@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/pkg/bin/python3.12
 # coding=utf-8
 #
 # Copyright (C) 2011 Nikita Kitaev
@@ -20,6 +20,7 @@
 """
 An Inkscape extension for exporting Synfig files (.sif)
 """
+
 import math
 import uuid
 from copy import deepcopy
@@ -69,9 +70,7 @@ class SynfigDocument(object):
         >
       <name>{}</name>
     </canvas>
-    """.format(
-                width, height, name
-            )
+    """.format(width, height, name)
         )
 
         self._update_viewbox()
@@ -157,9 +156,9 @@ class SynfigDocument(object):
 
         y = self.height - y
 
-        assert (
-            self.coor_svg2sif([x, y]) == vector
-        ), "sif to svg coordinate conversion error"
+        assert self.coor_svg2sif([x, y]) == vector, (
+            "sif to svg coordinate conversion error"
+        )
 
         return [x, y]
 
@@ -1410,9 +1409,11 @@ class SynfigExport(OutputExtension):
                     {
                         "bline": bline,
                         "color": color,
-                        "winding_style": 1
-                        if style.setdefault("fill-rule", "nonzero") == "evenodd"
-                        else 0,
+                        "winding_style": (
+                            1
+                            if style.setdefault("fill-rule", "nonzero") == "evenodd"
+                            else 0
+                        ),
                     },
                     guids={"bline": bline_guid},
                 )
@@ -1443,15 +1444,21 @@ class SynfigExport(OutputExtension):
                         "bline": bline,
                         "color": color,
                         "width": extract_width(style, "stroke-width", mtx),
-                        "sharp_cusps": True
-                        if style.setdefault("stroke-linejoin", "miter") == "miter"
-                        else False,
-                        "round_tip[0]": False
-                        if style.setdefault("stroke-linecap", "butt") == "butt"
-                        else True,
-                        "round_tip[1]": False
-                        if style.setdefault("stroke-linecap", "butt") == "butt"
-                        else True,
+                        "sharp_cusps": (
+                            True
+                            if style.setdefault("stroke-linejoin", "miter") == "miter"
+                            else False
+                        ),
+                        "round_tip[0]": (
+                            False
+                            if style.setdefault("stroke-linecap", "butt") == "butt"
+                            else True
+                        ),
+                        "round_tip[1]": (
+                            False
+                            if style.setdefault("stroke-linecap", "butt") == "butt"
+                            else True
+                        ),
                     },
                     guids={"bline": bline_guid},
                 )
